@@ -1,7 +1,7 @@
 #############################################################################
 #
 # XLConnect
-# Copyright (C) 2010-2017 Mirai Solutions GmbH
+# Copyright (C) 2010-2018 Mirai Solutions GmbH
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -33,7 +33,7 @@ setMethod("getActiveSheetIndex",
 		signature(object = "workbook"), 
 		function(object) {
 			# Note: Java has 0-based indices
-			idx <- as.integer(jTryCatch(object@jobj$getActiveSheetIndex()) + 1)
+		  idx <- as.integer(xlcCall(object, "getActiveSheetIndex", .recycle = FALSE) + 1)
 			ifelse(idx > 0, idx, NA)
 		}
 )
